@@ -13,12 +13,12 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 #
-
 import os
 import json
 from contextlib import closing
+
 from flow_sdk.client.api.base import BaseFlowAPI
-from flow_sdk.utils import preprocess, check_config, download_from_request, get_parser_version_set
+from flow_sdk.utils import preprocess, check_config, download_from_request
 
 
 class Job(BaseFlowAPI):
@@ -32,19 +32,13 @@ class Job(BaseFlowAPI):
         config_data, dsl_data = preprocess(**kwargs)
         return self._post(url='job/data/view/query', json=config_data)
 
-    def submit(self, conf_path, dsl_path=None):
-        if not os.path.exists(conf_path):
-            raise FileNotFoundError('Invalid conf path, file not exists.')
-
+    def submit(self, config_data, dsl_data=None):
         kwargs = locals()
-
         config_data, dsl_data = preprocess(**kwargs)
-        post_data = {
+        return self._post(url='job/submit', json={
+            'job_runtime_conf': config_data,
             'job_dsl': dsl_data,
-            'job_runtime_conf': config_data
-        }
-
-        return self._post(url='job/submit', json=post_data)
+        })
 
     def stop(self, job_id):
         job_id = str(job_id)
@@ -87,7 +81,7 @@ class Job(BaseFlowAPI):
         job_id = config_data['job_id']
         tar_file_name = 'job_{}_log.tar.gz'.format(job_id)
         extract_dir = os.path.join(config_data['output_path'], 'job_{}_log'.format(job_id))
-        with closing(self._get(url='job/log', handle_result=False, json=config_data, stream=True)) as response:
+        with closing(self._post(url='job/log/download', handle_result=False, json=config_data, stream=True)) as response:
             if response.status_code == 200:
                 download_from_request(http_response=response, tar_file_name=tar_file_name, extract_dir=extract_dir)
                 response = {'retcode': 0,
@@ -97,23 +91,17 @@ class Job(BaseFlowAPI):
                 response = response.json()
         return response
 
-    def generate_dsl(self, train_dsl_path, cpn_file_path=None, cpn_list: list = None):
-        kwargs = locals()
-        if not os.path.exists(kwargs.get("train_dsl_path")):
-            raise Exception("Train dsl file not exists.")
-        if kwargs.get("cpn_list"):
-            cpn_str = kwargs.get("cpn_list")
-        elif kwargs.get("cpn_file_path"):
-            with open(kwargs.get("cpn_file_path"), "r") as fp:
-                cpn_str = fp.read()
-        else:
-            cpn_str = ""
+    def generate_dsl(self, train_dsl, cpn):
+        """
+        @param train_dsl: dict or str
+        @param cpn: list or str
+        """
 
-        with open(kwargs.get("train_dsl_path"), "r") as ft:
-            train_dsl = ft.read()
+        if isinstance(train_dsl, dict):
+            train_dsl = json.dumps(train_dsl)
 
         config_data = {
-            "cpn_str": cpn_str,
+            "cpn_str": cpn,
             "train_dsl": train_dsl,
             "version": "2"
         }
