@@ -30,7 +30,6 @@ from pipeline.component.scale import FeatureScale
 from pipeline.component.union import Union
 from pipeline.component.feldman_verifiable_sum import FeldmanVerifiableSum
 from pipeline.component.sample_weight import SampleWeight
-from pipeline.component.sbt_feature_transformer import SBTTransformer
 from pipeline.component.feature_imputation import FeatureImputation
 from pipeline.component.label_transform import LabelTransform
 from pipeline.component.hetero_sshe_lr import HeteroSSHELR
@@ -47,7 +46,7 @@ __all__ = ["DataStatistics", "DataIO", "Evaluation", "HeteroDataSplit",
            "HomoLR", "HomoNN", "HomoSecureBoost", "HomoFeatureBinning", "Intersection",
            "LocalBaseline", "OneHotEncoder", "PSI", "Reader", "Scorecard",
            "FederatedSample", "FeatureScale", "Union", "ColumnExpand", "FeldmanVerifiableSum",
-           "SampleWeight", "DataTransform", "SBTTransformer", "FeatureImputation",
+           "SampleWeight", "DataTransform", "FeatureImputation",
            "LabelTransform", "SecureInformationRetrieval", "CacheLoader", "ModelLoader",
            "HeteroSSHELR", "HeteroKmeans", "HomoOneHotEncoder"]
 
