@@ -14,7 +14,12 @@
 #  limitations under the License.
 #
 
-import torch.nn as nn
+_TORCH_VALID = False
+try:
+    import torch.nn as nn
+    _TORCH_VALID = True
+except ImportError:
+    pass
 
 
 def build_model(model_type="sequential"):
@@ -26,6 +31,9 @@ def build_model(model_type="sequential"):
 
 class SequentialModel(object):
     def __init__(self):
-        self._model = nn.Sequential()
+        if _TORCH_VALID:
+            self._model = nn.Sequential()
+        else:
+            self._model = None
 
 
