@@ -2,7 +2,8 @@ from pipeline.interface.data import Data
 from pipeline.interface.input import Input
 from pipeline.interface.output import Output
 from pipeline.interface.model import Model
+from pipeline.interface.cache import Cache
 
 
-__all__ = ["Data", "Input", "Output", "Model"]
+__all__ = ["Data", "Input", "Output", "Model", "Cache"]
 
