@@ -374,80 +374,115 @@ class HeteroBoostingParam(BoostingParam):
 
 class HeteroSecureBoostParam(HeteroBoostingParam):
     """
-        Define boosting tree parameters that used in federated ml.
+    Define boosting tree parameters that used in federated ml.
 
-        Parameters
-        ----------
-        task_type : str, accepted 'classification', 'regression' only, default: 'classification'
+    Parameters
+    ----------
+    task_type : {'classification', 'regression'}, default: 'classification'
+        task type
 
-        tree_param : DecisionTreeParam Object, default: DecisionTreeParam()
+    tree_param : DecisionTreeParam Object, default: DecisionTreeParam()
+        tree param
 
-        objective_param : ObjectiveParam Object, default: ObjectiveParam()
+    objective_param : ObjectiveParam Object, default: ObjectiveParam()
+        objective param
 
-        learning_rate : float, accepted float, int or long only, the learning rate of secure boost. default: 0.3
+    learning_rate : float, int or long
+        the learning rate of secure boost. default: 0.3
 
-        num_trees : int, accepted int, float only, the max number of trees to build. default: 5
+    num_trees : int or float
+        the max number of trees to build. default: 5
 
-        subsample_feature_rate : float, a float-number in [0, 1], default: 1.0
+    subsample_feature_rate : float
+        a float-number in [0, 1], default: 1.0
 
-        random_seed: seed that controls all random functions
+    random_seed: int
+        seed that controls all random functions
 
-        n_iter_no_change : bool,
-            when True and residual error less than tol, tree building process will stop. default: True
+    n_iter_no_change : bool,
+        when True and residual error less than tol, tree building process will stop. default: True
 
-        encrypt_param : EncodeParam Object, encrypt method use in secure boost, default: EncryptParam(), this parameter
-                        is only for hetero-secureboost
+    encrypt_param : EncodeParam Object
+        encrypt method use in secure boost, default: EncryptParam(), this parameter
+        is only for hetero-secureboost
 
-        bin_num: int, positive integer greater than 1, bin number use in quantile. default: 32
+    bin_num: positive integer greater than 1
+        bin number use in quantile. default: 32
 
-        encrypted_mode_calculator_param: EncryptedModeCalculatorParam object, the calculation mode use in secureboost,
-                                         default: EncryptedModeCalculatorParam(), only for hetero-secureboost
+    encrypted_mode_calculator_param: EncryptedModeCalculatorParam object
+        the calculation mode use in secureboost, default: EncryptedModeCalculatorParam(), only for hetero-secureboost
 
-        use_missing: bool, accepted True, False only, use missing value in training process or not. default: False
+    use_missing: bool
+        use missing value in training process or not. default: False
 
-        zero_as_missing: bool, accepted True, False only, regard 0 as missing value or not,
-                         will be use only if use_missing=True, default: False
+    zero_as_missing: bool
+        regard 0 as missing value or not, will be use only if use_missing=True, default: False
 
-        validation_freqs: None or positive integer or container object in python. Do validation in training process or Not.
-                          if equals None, will not do validation in train process;
-                          if equals positive integer, will validate data every validation_freqs epochs passes;
-                          if container object in python, will validate data if epochs belong to this container.
-                            e.g. validation_freqs = [10, 15], will validate data when epoch equals to 10 and 15.
-                          Default: None
-                          The default value is None, 1 is suggested. You can set it to a number larger than 1 in order to
-                          speed up training by skipping validation rounds. When it is larger than 1, a number which is
-                          divisible by "num_trees" is recommended, otherwise, you will miss the validation scores
-                          of last training iteration.
+    validation_freqs: None or positive integer or container object in python
+        Do validation in training process or Not.
+        if equals None, will not do validation in train process;
+        if equals positive integer, will validate data every validation_freqs epochs passes;
+        if container object in python, will validate data if epochs belong to this container.
+        e.g. validation_freqs = [10, 15], will validate data when epoch equals to 10 and 15.
+        Default: None
+        The default value is None, 1 is suggested. You can set it to a number larger than 1 in order to
+        speed up training by skipping validation rounds. When it is larger than 1, a number which is
+        divisible by "num_trees" is recommended, otherwise, you will miss the validation scores
+        of last training iteration.
 
-        early_stopping_rounds: should be a integer larger than 0，will stop training if one metric of one validation data
-                                doesn’t improve in last early_stopping_round rounds，
-                                need to set validation freqs and will check early_stopping every at every validation epoch,
+    early_stopping_rounds: integer larger than 0
+        will stop training if one metric of one validation data
+        doesn’t improve in last early_stopping_round rounds，
+        need to set validation freqs and will check early_stopping every at every validation epoch,
 
-        metrics: list, default: []
-                 Specify which metrics to be used when performing evaluation during training process.
-                 If set as empty, default metrics will be used. For regression tasks, default metrics are
-                 ['root_mean_squared_error', 'mean_absolute_error']， For binary-classificatiin tasks, default metrics
-                 are ['auc', 'ks']. For multi-classification tasks, default metrics are ['accuracy', 'precision', 'recall']
+    metrics: list, default: []
+        Specify which metrics to be used when performing evaluation during training process.
+        If set as empty, default metrics will be used. For regression tasks, default metrics are
+        ['root_mean_squared_error', 'mean_absolute_error']， For binary-classificatiin tasks, default metrics
+        are ['auc', 'ks']. For multi-classification tasks, default metrics are ['accuracy', 'precision', 'recall']
 
-        use_first_metric_only: use only the first metric for early stopping
+    use_first_metric_only: bool
+        use only the first metric for early stopping
 
-        complete_secure: bool, if use complete_secure, when use complete secure, build first tree using only guest
-                        features
+    complete_secure: bool
+        if use complete_secure, when use complete secure, build first tree using only guest features
 
-        sparse_optimization: this parameter is now abandoned
+    sparse_optimization:
+        this parameter is abandoned in FATE-1.7.1
 
-        run_goss: bool, activate Gradient-based One-Side Sampling, which selects large gradient and small
-                   gradient samples using top_rate and other_rate.
+    run_goss: bool
+        activate Gradient-based One-Side Sampling, which selects large gradient and small
+        gradient samples using top_rate and other_rate.
 
-        top_rate: float, the retain ratio of large gradient data, used when run_goss is True
+    top_rate: float
+        the retain ratio of large gradient data, used when run_goss is True
 
-        other_rate: float, the retain ratio of small gradient data, used when run_goss is True
+    other_rate: float
+        the retain ratio of small gradient data, used when run_goss is True
 
-        cipher_compress_error： This param is now abandoned
+    cipher_compress_error: {None}
+        This param is now abandoned
 
-        cipher_compress: bool, default is True, use cipher compressing to reduce computation cost and transfer cost
+    cipher_compress: bool
+        default is True, use cipher compressing to reduce computation cost and transfer cost
 
-        """
+    EINI_inference: bool
+        default is False, this option changes the inference algorithm used in predict tasks.
+        a secure prediction method that hides decision path to enhance security in the inference
+        step. This method is insprired by EINI inference algorithm.
+
+    EINI_random_mask: bool
+        default is False
+        multiply predict result by a random float number to confuse original predict result. This operation further
+        enhances the security of naive EINI algorithm.
+
+    EINI_complexity_check: bool
+        default is False
+        check the complexity of tree models when running EINI algorithms. Complexity models are easy to hide their
+        decision path, while simple tree models are not, therefore if a tree model is too simple, it is not allowed
+        to run EINI predict algorithms.
+
+    """
 
     def __init__(self, tree_param: DecisionTreeParam = DecisionTreeParam(), task_type=consts.CLASSIFICATION,
                  objective_param=ObjectiveParam(),
@@ -461,7 +496,8 @@ class HeteroSecureBoostParam(HeteroBoostingParam):
                  binning_error=consts.DEFAULT_RELATIVE_ERROR,
                  sparse_optimization=False, run_goss=False, top_rate=0.2, other_rate=0.1,
                  cipher_compress_error=None, cipher_compress=True, new_ver=True,
-                 callback_param=CallbackParam()):
+                 callback_param=CallbackParam(), EINI_inference=False, EINI_random_mask=False,
+                 EINI_complexity_check=False):
 
         super(HeteroSecureBoostParam, self).__init__(task_type, objective_param, learning_rate, num_trees,
                                                      subsample_feature_rate, n_iter_no_change, tol, encrypt_param,
@@ -482,6 +518,9 @@ class HeteroSecureBoostParam(HeteroBoostingParam):
         self.cipher_compress_error = cipher_compress_error
         self.cipher_compress = cipher_compress
         self.new_ver = new_ver
+        self.EINI_inference = EINI_inference
+        self.EINI_random_mask = EINI_random_mask
+        self.EINI_complexity_check = EINI_complexity_check
         self.callback_param = copy.deepcopy(callback_param)
 
     def check(self):
@@ -493,7 +532,6 @@ class HeteroSecureBoostParam(HeteroBoostingParam):
         if type(self.zero_as_missing) != bool:
             raise ValueError('zero as missing should be bool type')
         self.check_boolean(self.complete_secure, 'complete_secure')
-        self.check_boolean(self.sparse_optimization, 'sparse optimization')
         self.check_boolean(self.run_goss, 'run goss')
         self.check_decimal_float(self.top_rate, 'top rate')
         self.check_decimal_float(self.other_rate, 'other rate')
@@ -501,13 +539,38 @@ class HeteroSecureBoostParam(HeteroBoostingParam):
         self.check_positive_number(self.top_rate, 'top_rate')
         self.check_boolean(self.new_ver, 'code version switcher')
         self.check_boolean(self.cipher_compress, 'cipher compress')
+        self.check_boolean(self.EINI_inference, 'eini inference')
+        self.check_boolean(self.EINI_random_mask, 'eini random mask')
+        self.check_boolean(self.EINI_complexity_check, 'eini complexity check')
+
+        for p in ["early_stopping_rounds", "validation_freqs", "metrics",
+                  "use_first_metric_only"]:
+            # if self._warn_to_deprecate_param(p, "", ""):
+            if self._deprecated_params_set.get(p):
+                if "callback_param" in self.get_user_feeded():
+                    raise ValueError(f"{p} and callback param should not be set simultaneously，"
+                                     f"{self._deprecated_params_set}, {self.get_user_feeded()}")
+                else:
+                    self.callback_param.callbacks = ["PerformanceEvaluate"]
+                break
+
+        descr = "boosting_param's"
+
+        if self._warn_to_deprecate_param("validation_freqs", descr, "callback_param's 'validation_freqs'"):
+            self.callback_param.validation_freqs = self.validation_freqs
+
+        if self._warn_to_deprecate_param("early_stopping_rounds", descr, "callback_param's 'early_stopping_rounds'"):
+            self.callback_param.early_stopping_rounds = self.early_stopping_rounds
+
+        if self._warn_to_deprecate_param("metrics", descr, "callback_param's 'metrics'"):
+            self.callback_param.metrics = self.metrics
+
+        if self._warn_to_deprecate_param("use_first_metric_only", descr, "callback_param's 'use_first_metric_only'"):
+            self.callback_param.use_first_metric_only = self.use_first_metric_only
 
         if self.top_rate + self.other_rate >= 1:
             raise ValueError('sum of top rate and other rate should be smaller than 1')
 
-        if self.sparse_optimization and self.cipher_compress:
-            raise ValueError('cipher compress is not supported in sparse optimization mode')
-
         return True
 
 
@@ -524,22 +587,25 @@ class HeteroFastSecureBoostParam(HeteroSecureBoostParam):
                  complete_secure=False, tree_num_per_party=1, guest_depth=1, host_depth=1, work_mode='mix', metrics=None,
                  sparse_optimization=False, random_seed=100, binning_error=consts.DEFAULT_RELATIVE_ERROR,
                  cipher_compress_error=None, new_ver=True, run_goss=False, top_rate=0.2, other_rate=0.1,
-                 cipher_compress=True, callback_param=CallbackParam()):
+                 cipher_compress=True, callback_param=CallbackParam(), EINI_inference=True, EINI_random_mask=False,
+                 EINI_complexity_check=False):
 
         """
-        work_mode：
-            mix:  alternate using guest/host features to build trees. For example, the first 'tree_num_per_party' trees use guest features,
-                  the second k trees use host features, and so on
+        Parameters
+        ----------
+        work_mode: {"mix", "layered"}
+            mix:  alternate using guest/host features to build trees. For example, the first 'tree_num_per_party' trees
+                  use guest features, the second k trees use host features, and so on
             layered: only support 2 party, when running layered mode, first 'host_depth' layer will use host features,
                      and then next 'guest_depth' will only use guest features
-        tree_num_per_party: every party will alternate build 'tree_num_per_party' trees until reach max tree num, this param is valid when work_mode is
-            mix
-        guest_depth: guest will build last guest_depth of a decision tree using guest features, is valid when work mode
-            is layered
-        host depth: host will build first host_depth of a decision tree using host features, is valid when work mode is
-            layered
+        tree_num_per_party: int
+            every party will alternate build 'tree_num_per_party' trees until reach max tree num, this param is valid
+             when work_mode is mix
+        guest_depth: int
+            guest will build last guest_depth of a decision tree using guest features, is valid when work mode is layered
+        host depth: int
+            host will build first host_depth of a decision tree using host features, is valid when work mode is layered
 
-        other params are the same as HeteroSecureBoost
         """
 
         super(HeteroFastSecureBoostParam, self).__init__(tree_param, task_type, objective_param, learning_rate,
@@ -553,7 +619,10 @@ class HeteroFastSecureBoostParam(HeteroSecureBoostParam):
                                                          cipher_compress_error=cipher_compress_error,
                                                          new_ver=new_ver,
                                                          cipher_compress=cipher_compress,
-                                                         run_goss=run_goss, top_rate=top_rate, other_rate=other_rate
+                                                         run_goss=run_goss, top_rate=top_rate, other_rate=other_rate,
+                                                         EINI_inference=EINI_inference,
+                                                         EINI_random_mask=EINI_random_mask,
+                                                         EINI_complexity_check=EINI_complexity_check
                                                          )
 
         self.tree_num_per_party = tree_num_per_party
