@@ -20,6 +20,7 @@
 import copy
 
 from pipeline.param.base_param import BaseParam
+from pipeline.param.callback_param import CallbackParam
 from pipeline.param.encrypt_param import EncryptParam
 from pipeline.param.encrypted_mode_calculation_param import EncryptedModeCalculatorParam
 from pipeline.param.cross_validation_param import CrossValidationParam
@@ -36,17 +37,17 @@ class LinearParam(BaseParam):
 
     Parameters
     ----------
-    penalty : str, 'L1' or 'L2'. default: 'L2'
+    penalty : {'L2' or 'L1'}
         Penalty method used in LinR. Please note that, when using encrypted version in HeteroLinR,
         'L1' is not supported.
 
-    tol : float, default: 1e-5
+    tol : float, default: 1e-4
         The tolerance of convergence
 
     alpha : float, default: 1.0
         Regularization strength coefficient.
 
-    optimizer : str, 'sgd', 'rmsprop', 'adam', 'sqn', or 'adagrad', default: 'sgd'
+    optimizer : {'sgd', 'rmsprop', 'adam', 'sqn', 'adagrad'}
         Optimize method
 
     batch_size : int, default: -1
@@ -55,25 +56,29 @@ class LinearParam(BaseParam):
     learning_rate : float, default: 0.01
         Learning rate
 
-    max_iter : int, default: 100
+    max_iter : int, default: 20
         The maximum iteration for training.
 
     init_param: InitParam object, default: default InitParam object
         Init param method object.
 
-    early_stop : str, 'diff' or 'abs' or 'weight_dff', default: 'diff'
+    early_stop : {'diff', 'abs', 'weight_dff'}
         Method used to judge convergence.
             a)	diff： Use difference of loss between two iterations to judge whether converge.
             b)	abs: Use the absolute value of loss to judge whether converge. i.e. if loss < tol, it is converged.
             c)  weight_diff: Use difference between weights of two consecutive iterations
 
     predict_param: PredictParam object, default: default PredictParam object
+        predict param
 
     encrypt_param: EncryptParam object, default: default EncryptParam object
+        encrypt param
 
     encrypted_mode_calculator_param: EncryptedModeCalculatorParam object, default: default EncryptedModeCalculatorParam object
+        encrypted mode calculator param
 
     cv_param: CrossValidationParam object, default: default CrossValidationParam object
+        cv param
 
     decay: int or float, default: 1
         Decay rate for learning rate. learning rate will follow the following decay schedule.
@@ -99,9 +104,12 @@ class LinearParam(BaseParam):
     use_first_metric_only: bool, default: False
         Indicate whether to use the first metric in `metrics` as the only criterion for early stopping judgement.
 
-    floating_point_precision: None or integer, if not None, use floating_point_precision-bit to speed up calculation,
-                               e.g.: convert an x to round(x * 2**floating_point_precision) during Paillier operation, divide
-                                      the result by 2**floating_point_precision in the end.
+    floating_point_precision: None or integer
+        if not None, use floating_point_precision-bit to speed up calculation,
+        e.g.: convert an x to round(x * 2**floating_point_precision) during Paillier operation, divide
+                the result by 2**floating_point_precision in the end.
+    callback_param: CallbackParam object
+        callback param
 
     """
 
@@ -113,7 +121,7 @@ class LinearParam(BaseParam):
                  encrypted_mode_calculator_param=EncryptedModeCalculatorParam(),
                  cv_param=CrossValidationParam(), decay=1, decay_sqrt=True, validation_freqs=None,
                  early_stopping_rounds=None, stepwise_param=StepwiseParam(), metrics=None, use_first_metric_only=False,
-                 floating_point_precision=23):
+                 floating_point_precision=23, callback_param=CallbackParam()):
         super(LinearParam, self).__init__()
         self.penalty = penalty
         self.tol = tol
@@ -137,6 +145,7 @@ class LinearParam(BaseParam):
         self.metrics = metrics or []
         self.use_first_metric_only = use_first_metric_only
         self.floating_point_precision = floating_point_precision
+        self.callback_param = copy.deepcopy(callback_param)
 
     def check(self):
         descr = "linear_regression_param's "
@@ -247,4 +256,5 @@ class LinearParam(BaseParam):
                  self.floating_point_precision < 0 or self.floating_point_precision > 64):
             raise ValueError("floating point precision should be null or a integer between 0 and 64")
 
+        self.callback_param.check()
         return True
